# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ActiveDirectoryAddGroupsArgs', 'ActiveDirectoryAddGroups']

@pulumi.input_type
class ActiveDirectoryAddGroupsArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[builtins.str],
                 join_point_id: pulumi.Input[builtins.str],
                 ad_scopes_names: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_domain_allowed_list: Optional[pulumi.Input[builtins.bool]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryAddGroupsGroupArgs']]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ActiveDirectoryAddGroups resource.
        :param pulumi.Input[builtins.str] domain: AD domain associated with the join point
        :param pulumi.Input[builtins.str] join_point_id: Active Directory Join Point ID
        :param pulumi.Input[builtins.str] ad_scopes_names: String that contains the names of the scopes that the active directory belongs to. Names are separated by comm - Default
               value: `Default_Scope`
        :param pulumi.Input[builtins.str] description: Join point Description
        :param pulumi.Input[builtins.bool] enable_domain_allowed_list: - Default value: `true`
        :param pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryAddGroupsGroupArgs']]] groups: List of AD Groups
        :param pulumi.Input[builtins.str] name: The name of the active directory join point
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "join_point_id", join_point_id)
        if ad_scopes_names is not None:
            pulumi.set(__self__, "ad_scopes_names", ad_scopes_names)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_domain_allowed_list is not None:
            pulumi.set(__self__, "enable_domain_allowed_list", enable_domain_allowed_list)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[builtins.str]:
        """
        AD domain associated with the join point
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="joinPointId")
    def join_point_id(self) -> pulumi.Input[builtins.str]:
        """
        Active Directory Join Point ID
        """
        return pulumi.get(self, "join_point_id")

    @join_point_id.setter
    def join_point_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "join_point_id", value)

    @property
    @pulumi.getter(name="adScopesNames")
    def ad_scopes_names(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        String that contains the names of the scopes that the active directory belongs to. Names are separated by comm - Default
        value: `Default_Scope`
        """
        return pulumi.get(self, "ad_scopes_names")

    @ad_scopes_names.setter
    def ad_scopes_names(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ad_scopes_names", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Join point Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableDomainAllowedList")
    def enable_domain_allowed_list(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        - Default value: `true`
        """
        return pulumi.get(self, "enable_domain_allowed_list")

    @enable_domain_allowed_list.setter
    def enable_domain_allowed_list(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_domain_allowed_list", value)

    @property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryAddGroupsGroupArgs']]]]:
        """
        List of AD Groups
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryAddGroupsGroupArgs']]]]):
        pulumi.set(self, "groups", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the active directory join point
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ActiveDirectoryAddGroupsState:
    def __init__(__self__, *,
                 ad_scopes_names: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 enable_domain_allowed_list: Optional[pulumi.Input[builtins.bool]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryAddGroupsGroupArgs']]]] = None,
                 join_point_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ActiveDirectoryAddGroups resources.
        :param pulumi.Input[builtins.str] ad_scopes_names: String that contains the names of the scopes that the active directory belongs to. Names are separated by comm - Default
               value: `Default_Scope`
        :param pulumi.Input[builtins.str] description: Join point Description
        :param pulumi.Input[builtins.str] domain: AD domain associated with the join point
        :param pulumi.Input[builtins.bool] enable_domain_allowed_list: - Default value: `true`
        :param pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryAddGroupsGroupArgs']]] groups: List of AD Groups
        :param pulumi.Input[builtins.str] join_point_id: Active Directory Join Point ID
        :param pulumi.Input[builtins.str] name: The name of the active directory join point
        """
        if ad_scopes_names is not None:
            pulumi.set(__self__, "ad_scopes_names", ad_scopes_names)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if enable_domain_allowed_list is not None:
            pulumi.set(__self__, "enable_domain_allowed_list", enable_domain_allowed_list)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if join_point_id is not None:
            pulumi.set(__self__, "join_point_id", join_point_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="adScopesNames")
    def ad_scopes_names(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        String that contains the names of the scopes that the active directory belongs to. Names are separated by comm - Default
        value: `Default_Scope`
        """
        return pulumi.get(self, "ad_scopes_names")

    @ad_scopes_names.setter
    def ad_scopes_names(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ad_scopes_names", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Join point Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        AD domain associated with the join point
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="enableDomainAllowedList")
    def enable_domain_allowed_list(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        - Default value: `true`
        """
        return pulumi.get(self, "enable_domain_allowed_list")

    @enable_domain_allowed_list.setter
    def enable_domain_allowed_list(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_domain_allowed_list", value)

    @property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryAddGroupsGroupArgs']]]]:
        """
        List of AD Groups
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ActiveDirectoryAddGroupsGroupArgs']]]]):
        pulumi.set(self, "groups", value)

    @property
    @pulumi.getter(name="joinPointId")
    def join_point_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Active Directory Join Point ID
        """
        return pulumi.get(self, "join_point_id")

    @join_point_id.setter
    def join_point_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "join_point_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the active directory join point
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


class ActiveDirectoryAddGroups(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ad_scopes_names: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 enable_domain_allowed_list: Optional[pulumi.Input[builtins.bool]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ActiveDirectoryAddGroupsGroupArgs', 'ActiveDirectoryAddGroupsGroupArgsDict']]]]] = None,
                 join_point_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage an Active Directory Add Groups.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.ActiveDirectoryAddGroups("example",
            join_point_id="73808580-b6e6-11ee-8960-de6d7692bc40",
            name="cisco.local",
            description="My AD join point",
            domain="cisco.local",
            ad_scopes_names="Default_Scope",
            enable_domain_allowed_list=True,
            groups=[{
                "name": "cisco.local/operators",
                "sid": "S-1-5-32-548",
                "type": "GLOBAL",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] ad_scopes_names: String that contains the names of the scopes that the active directory belongs to. Names are separated by comm - Default
               value: `Default_Scope`
        :param pulumi.Input[builtins.str] description: Join point Description
        :param pulumi.Input[builtins.str] domain: AD domain associated with the join point
        :param pulumi.Input[builtins.bool] enable_domain_allowed_list: - Default value: `true`
        :param pulumi.Input[Sequence[pulumi.Input[Union['ActiveDirectoryAddGroupsGroupArgs', 'ActiveDirectoryAddGroupsGroupArgsDict']]]] groups: List of AD Groups
        :param pulumi.Input[builtins.str] join_point_id: Active Directory Join Point ID
        :param pulumi.Input[builtins.str] name: The name of the active directory join point
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ActiveDirectoryAddGroupsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage an Active Directory Add Groups.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.ActiveDirectoryAddGroups("example",
            join_point_id="73808580-b6e6-11ee-8960-de6d7692bc40",
            name="cisco.local",
            description="My AD join point",
            domain="cisco.local",
            ad_scopes_names="Default_Scope",
            enable_domain_allowed_list=True,
            groups=[{
                "name": "cisco.local/operators",
                "sid": "S-1-5-32-548",
                "type": "GLOBAL",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param ActiveDirectoryAddGroupsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ActiveDirectoryAddGroupsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ad_scopes_names: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 enable_domain_allowed_list: Optional[pulumi.Input[builtins.bool]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ActiveDirectoryAddGroupsGroupArgs', 'ActiveDirectoryAddGroupsGroupArgsDict']]]]] = None,
                 join_point_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ActiveDirectoryAddGroupsArgs.__new__(ActiveDirectoryAddGroupsArgs)

            __props__.__dict__["ad_scopes_names"] = ad_scopes_names
            __props__.__dict__["description"] = description
            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            __props__.__dict__["enable_domain_allowed_list"] = enable_domain_allowed_list
            __props__.__dict__["groups"] = groups
            if join_point_id is None and not opts.urn:
                raise TypeError("Missing required property 'join_point_id'")
            __props__.__dict__["join_point_id"] = join_point_id
            __props__.__dict__["name"] = name
        super(ActiveDirectoryAddGroups, __self__).__init__(
            'ise:identitymanagement/activeDirectoryAddGroups:ActiveDirectoryAddGroups',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ad_scopes_names: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            enable_domain_allowed_list: Optional[pulumi.Input[builtins.bool]] = None,
            groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ActiveDirectoryAddGroupsGroupArgs', 'ActiveDirectoryAddGroupsGroupArgsDict']]]]] = None,
            join_point_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None) -> 'ActiveDirectoryAddGroups':
        """
        Get an existing ActiveDirectoryAddGroups resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] ad_scopes_names: String that contains the names of the scopes that the active directory belongs to. Names are separated by comm - Default
               value: `Default_Scope`
        :param pulumi.Input[builtins.str] description: Join point Description
        :param pulumi.Input[builtins.str] domain: AD domain associated with the join point
        :param pulumi.Input[builtins.bool] enable_domain_allowed_list: - Default value: `true`
        :param pulumi.Input[Sequence[pulumi.Input[Union['ActiveDirectoryAddGroupsGroupArgs', 'ActiveDirectoryAddGroupsGroupArgsDict']]]] groups: List of AD Groups
        :param pulumi.Input[builtins.str] join_point_id: Active Directory Join Point ID
        :param pulumi.Input[builtins.str] name: The name of the active directory join point
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ActiveDirectoryAddGroupsState.__new__(_ActiveDirectoryAddGroupsState)

        __props__.__dict__["ad_scopes_names"] = ad_scopes_names
        __props__.__dict__["description"] = description
        __props__.__dict__["domain"] = domain
        __props__.__dict__["enable_domain_allowed_list"] = enable_domain_allowed_list
        __props__.__dict__["groups"] = groups
        __props__.__dict__["join_point_id"] = join_point_id
        __props__.__dict__["name"] = name
        return ActiveDirectoryAddGroups(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="adScopesNames")
    def ad_scopes_names(self) -> pulumi.Output[builtins.str]:
        """
        String that contains the names of the scopes that the active directory belongs to. Names are separated by comm - Default
        value: `Default_Scope`
        """
        return pulumi.get(self, "ad_scopes_names")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Join point Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        AD domain associated with the join point
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="enableDomainAllowedList")
    def enable_domain_allowed_list(self) -> pulumi.Output[builtins.bool]:
        """
        - Default value: `true`
        """
        return pulumi.get(self, "enable_domain_allowed_list")

    @property
    @pulumi.getter
    def groups(self) -> pulumi.Output[Optional[Sequence['outputs.ActiveDirectoryAddGroupsGroup']]]:
        """
        List of AD Groups
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter(name="joinPointId")
    def join_point_id(self) -> pulumi.Output[builtins.str]:
        """
        Active Directory Join Point ID
        """
        return pulumi.get(self, "join_point_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the active directory join point
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetActiveDirectoryGroupsByDomainResult',
    'AwaitableGetActiveDirectoryGroupsByDomainResult',
    'get_active_directory_groups_by_domain',
    'get_active_directory_groups_by_domain_output',
]

@pulumi.output_type
class GetActiveDirectoryGroupsByDomainResult:
    """
    A collection of values returned by getActiveDirectoryGroupsByDomain.
    """
    def __init__(__self__, domain=None, filter=None, groups=None, id=None, join_point_id=None, sid_filter=None, type_filter=None):
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if join_point_id and not isinstance(join_point_id, str):
            raise TypeError("Expected argument 'join_point_id' to be a str")
        pulumi.set(__self__, "join_point_id", join_point_id)
        if sid_filter and not isinstance(sid_filter, str):
            raise TypeError("Expected argument 'sid_filter' to be a str")
        pulumi.set(__self__, "sid_filter", sid_filter)
        if type_filter and not isinstance(type_filter, str):
            raise TypeError("Expected argument 'type_filter' to be a str")
        pulumi.set(__self__, "type_filter", type_filter)

    @property
    @pulumi.getter
    def domain(self) -> builtins.str:
        """
        The domain whose groups we want to fetch
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def filter(self) -> Optional[builtins.str]:
        """
        Exact match filter on group's CN
        """
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetActiveDirectoryGroupsByDomainGroupResult']:
        """
        List of groups
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="joinPointId")
    def join_point_id(self) -> builtins.str:
        """
        Active Directory Join Point ID
        """
        return pulumi.get(self, "join_point_id")

    @property
    @pulumi.getter(name="sidFilter")
    def sid_filter(self) -> Optional[builtins.str]:
        """
        Exact match filter on group's SID, optionally specifying the domain as prefix. e.g. S-1-5-33-544 and R1.dom/S-1-5-33-544 are legal.
        """
        return pulumi.get(self, "sid_filter")

    @property
    @pulumi.getter(name="typeFilter")
    def type_filter(self) -> Optional[builtins.str]:
        """
        Can be exactly one of: BUILTIN, DOMAIN LOCAL, GLOBAL, UNIVERSAL.
        """
        return pulumi.get(self, "type_filter")


class AwaitableGetActiveDirectoryGroupsByDomainResult(GetActiveDirectoryGroupsByDomainResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetActiveDirectoryGroupsByDomainResult(
            domain=self.domain,
            filter=self.filter,
            groups=self.groups,
            id=self.id,
            join_point_id=self.join_point_id,
            sid_filter=self.sid_filter,
            type_filter=self.type_filter)


def get_active_directory_groups_by_domain(domain: Optional[builtins.str] = None,
                                          filter: Optional[builtins.str] = None,
                                          join_point_id: Optional[builtins.str] = None,
                                          sid_filter: Optional[builtins.str] = None,
                                          type_filter: Optional[builtins.str] = None,
                                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetActiveDirectoryGroupsByDomainResult:
    """
    This data source can read the Active Directory Groups By Domain.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_active_directory_groups_by_domain(join_point_id="73808580-b6e6-11ee-8960-de6d7692bc40",
        domain="cisco.com",
        filter="CN=ISE Admins",
        sid_filter="cisco.com/S-1-5-33-544",
        type_filter="UNIVERSAL")
    ```


    :param builtins.str domain: The domain whose groups we want to fetch
    :param builtins.str filter: Exact match filter on group's CN
    :param builtins.str join_point_id: Active Directory Join Point ID
    :param builtins.str sid_filter: Exact match filter on group's SID, optionally specifying the domain as prefix. e.g. S-1-5-33-544 and R1.dom/S-1-5-33-544 are legal.
    :param builtins.str type_filter: Can be exactly one of: BUILTIN, DOMAIN LOCAL, GLOBAL, UNIVERSAL.
    """
    __args__ = dict()
    __args__['domain'] = domain
    __args__['filter'] = filter
    __args__['joinPointId'] = join_point_id
    __args__['sidFilter'] = sid_filter
    __args__['typeFilter'] = type_filter
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getActiveDirectoryGroupsByDomain:getActiveDirectoryGroupsByDomain', __args__, opts=opts, typ=GetActiveDirectoryGroupsByDomainResult).value

    return AwaitableGetActiveDirectoryGroupsByDomainResult(
        domain=pulumi.get(__ret__, 'domain'),
        filter=pulumi.get(__ret__, 'filter'),
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        join_point_id=pulumi.get(__ret__, 'join_point_id'),
        sid_filter=pulumi.get(__ret__, 'sid_filter'),
        type_filter=pulumi.get(__ret__, 'type_filter'))
def get_active_directory_groups_by_domain_output(domain: Optional[pulumi.Input[builtins.str]] = None,
                                                 filter: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                 join_point_id: Optional[pulumi.Input[builtins.str]] = None,
                                                 sid_filter: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                 type_filter: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetActiveDirectoryGroupsByDomainResult]:
    """
    This data source can read the Active Directory Groups By Domain.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_active_directory_groups_by_domain(join_point_id="73808580-b6e6-11ee-8960-de6d7692bc40",
        domain="cisco.com",
        filter="CN=ISE Admins",
        sid_filter="cisco.com/S-1-5-33-544",
        type_filter="UNIVERSAL")
    ```


    :param builtins.str domain: The domain whose groups we want to fetch
    :param builtins.str filter: Exact match filter on group's CN
    :param builtins.str join_point_id: Active Directory Join Point ID
    :param builtins.str sid_filter: Exact match filter on group's SID, optionally specifying the domain as prefix. e.g. S-1-5-33-544 and R1.dom/S-1-5-33-544 are legal.
    :param builtins.str type_filter: Can be exactly one of: BUILTIN, DOMAIN LOCAL, GLOBAL, UNIVERSAL.
    """
    __args__ = dict()
    __args__['domain'] = domain
    __args__['filter'] = filter
    __args__['joinPointId'] = join_point_id
    __args__['sidFilter'] = sid_filter
    __args__['typeFilter'] = type_filter
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getActiveDirectoryGroupsByDomain:getActiveDirectoryGroupsByDomain', __args__, opts=opts, typ=GetActiveDirectoryGroupsByDomainResult)
    return __ret__.apply(lambda __response__: GetActiveDirectoryGroupsByDomainResult(
        domain=pulumi.get(__response__, 'domain'),
        filter=pulumi.get(__response__, 'filter'),
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        join_point_id=pulumi.get(__response__, 'join_point_id'),
        sid_filter=pulumi.get(__response__, 'sid_filter'),
        type_filter=pulumi.get(__response__, 'type_filter')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('ise')


class _ExportableConfig(types.ModuleType):
    @property
    def insecure(self) -> Optional[bool]:
        """
        Allow insecure HTTPS client. This can also be set as the ISE_INSECURE environment variable. Defaults to `true`.
        """
        return __config__.get_bool('insecure')

    @property
    def password(self) -> Optional[str]:
        """
        Password for the ISE instance. This can also be set as the ISE_PASSWORD environment variable.
        """
        return __config__.get('password')

    @property
    def retries(self) -> Optional[int]:
        """
        Number of retries for REST API calls. This can also be set as the ISE_RETRIES environment variable. Defaults to `3`.
        """
        return __config__.get_int('retries')

    @property
    def url(self) -> Optional[str]:
        """
        URL of the Cisco ISE instance. This can also be set as the ISE_URL environment variable.
        """
        return __config__.get('url')

    @property
    def username(self) -> Optional[str]:
        """
        Username for the ISE instance. This can also be set as the ISE_USERNAME environment variable.
        """
        return __config__.get('username')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EndpointArgs', 'Endpoint']

@pulumi.input_type
class EndpointArgs:
    def __init__(__self__, *,
                 mac: pulumi.Input[builtins.str],
                 static_group_assignment: pulumi.Input[builtins.bool],
                 static_profile_assignment: pulumi.Input[builtins.bool],
                 custom_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 identity_store: Optional[pulumi.Input[builtins.str]] = None,
                 identity_store_id: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_compliance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_enrolled: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_imei: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_jail_broken: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_manufacturer: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_model: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_os: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_phone_number: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_pinlock: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_reachable: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_serial: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_server_name: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 portal_user: Optional[pulumi.Input[builtins.str]] = None,
                 profile_id: Optional[pulumi.Input[builtins.str]] = None,
                 static_group_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None,
                 static_profile_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Endpoint resource.
        :param pulumi.Input[builtins.str] mac: MAC address of the endpoint
        :param pulumi.Input[builtins.bool] static_group_assignment: Static Group Assignment
        :param pulumi.Input[builtins.bool] static_profile_assignment: Static Profile Assignment
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] custom_attributes: Custom Attributes
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] group_id: Identity Group ID
        :param pulumi.Input[builtins.str] identity_store: Identity Store
        :param pulumi.Input[builtins.str] identity_store_id: Identity Store Id
        :param pulumi.Input[builtins.bool] mdm_compliance_status: Mdm Compliance Status
        :param pulumi.Input[builtins.bool] mdm_encrypted: Mdm Encrypted
        :param pulumi.Input[builtins.bool] mdm_enrolled: Mdm Enrolled
        :param pulumi.Input[builtins.str] mdm_imei: Mdm IMEI
        :param pulumi.Input[builtins.bool] mdm_jail_broken: Mdm JailBroken
        :param pulumi.Input[builtins.str] mdm_manufacturer: Mdm Manufacturer
        :param pulumi.Input[builtins.str] mdm_model: Mdm Model
        :param pulumi.Input[builtins.str] mdm_os: Mdm OS
        :param pulumi.Input[builtins.str] mdm_phone_number: Mdm PhoneNumber
        :param pulumi.Input[builtins.bool] mdm_pinlock: Mdm Pinlock
        :param pulumi.Input[builtins.bool] mdm_reachable: Mdm Reachable
        :param pulumi.Input[builtins.str] mdm_serial: Mdm Serial
        :param pulumi.Input[builtins.str] mdm_server_name: Mdm Server Name
        :param pulumi.Input[builtins.str] name: The name of the endpoint
        :param pulumi.Input[builtins.str] portal_user: Portal User
        :param pulumi.Input[builtins.str] profile_id: Profile ID
        :param pulumi.Input[builtins.bool] static_group_assignment_defined: staticGroupAssignmentDefined - Default value: `true`
        :param pulumi.Input[builtins.bool] static_profile_assignment_defined: Static Profile Assignment Defined - Default value: `true`
        """
        pulumi.set(__self__, "mac", mac)
        pulumi.set(__self__, "static_group_assignment", static_group_assignment)
        pulumi.set(__self__, "static_profile_assignment", static_profile_assignment)
        if custom_attributes is not None:
            pulumi.set(__self__, "custom_attributes", custom_attributes)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if identity_store is not None:
            pulumi.set(__self__, "identity_store", identity_store)
        if identity_store_id is not None:
            pulumi.set(__self__, "identity_store_id", identity_store_id)
        if mdm_compliance_status is not None:
            pulumi.set(__self__, "mdm_compliance_status", mdm_compliance_status)
        if mdm_encrypted is not None:
            pulumi.set(__self__, "mdm_encrypted", mdm_encrypted)
        if mdm_enrolled is not None:
            pulumi.set(__self__, "mdm_enrolled", mdm_enrolled)
        if mdm_imei is not None:
            pulumi.set(__self__, "mdm_imei", mdm_imei)
        if mdm_jail_broken is not None:
            pulumi.set(__self__, "mdm_jail_broken", mdm_jail_broken)
        if mdm_manufacturer is not None:
            pulumi.set(__self__, "mdm_manufacturer", mdm_manufacturer)
        if mdm_model is not None:
            pulumi.set(__self__, "mdm_model", mdm_model)
        if mdm_os is not None:
            pulumi.set(__self__, "mdm_os", mdm_os)
        if mdm_phone_number is not None:
            pulumi.set(__self__, "mdm_phone_number", mdm_phone_number)
        if mdm_pinlock is not None:
            pulumi.set(__self__, "mdm_pinlock", mdm_pinlock)
        if mdm_reachable is not None:
            pulumi.set(__self__, "mdm_reachable", mdm_reachable)
        if mdm_serial is not None:
            pulumi.set(__self__, "mdm_serial", mdm_serial)
        if mdm_server_name is not None:
            pulumi.set(__self__, "mdm_server_name", mdm_server_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if portal_user is not None:
            pulumi.set(__self__, "portal_user", portal_user)
        if profile_id is not None:
            pulumi.set(__self__, "profile_id", profile_id)
        if static_group_assignment_defined is not None:
            pulumi.set(__self__, "static_group_assignment_defined", static_group_assignment_defined)
        if static_profile_assignment_defined is not None:
            pulumi.set(__self__, "static_profile_assignment_defined", static_profile_assignment_defined)

    @property
    @pulumi.getter
    def mac(self) -> pulumi.Input[builtins.str]:
        """
        MAC address of the endpoint
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "mac", value)

    @property
    @pulumi.getter(name="staticGroupAssignment")
    def static_group_assignment(self) -> pulumi.Input[builtins.bool]:
        """
        Static Group Assignment
        """
        return pulumi.get(self, "static_group_assignment")

    @static_group_assignment.setter
    def static_group_assignment(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "static_group_assignment", value)

    @property
    @pulumi.getter(name="staticProfileAssignment")
    def static_profile_assignment(self) -> pulumi.Input[builtins.bool]:
        """
        Static Profile Assignment
        """
        return pulumi.get(self, "static_profile_assignment")

    @static_profile_assignment.setter
    def static_profile_assignment(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "static_profile_assignment", value)

    @property
    @pulumi.getter(name="customAttributes")
    def custom_attributes(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Custom Attributes
        """
        return pulumi.get(self, "custom_attributes")

    @custom_attributes.setter
    def custom_attributes(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "custom_attributes", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identity Group ID
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="identityStore")
    def identity_store(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identity Store
        """
        return pulumi.get(self, "identity_store")

    @identity_store.setter
    def identity_store(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "identity_store", value)

    @property
    @pulumi.getter(name="identityStoreId")
    def identity_store_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identity Store Id
        """
        return pulumi.get(self, "identity_store_id")

    @identity_store_id.setter
    def identity_store_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "identity_store_id", value)

    @property
    @pulumi.getter(name="mdmComplianceStatus")
    def mdm_compliance_status(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Compliance Status
        """
        return pulumi.get(self, "mdm_compliance_status")

    @mdm_compliance_status.setter
    def mdm_compliance_status(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_compliance_status", value)

    @property
    @pulumi.getter(name="mdmEncrypted")
    def mdm_encrypted(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Encrypted
        """
        return pulumi.get(self, "mdm_encrypted")

    @mdm_encrypted.setter
    def mdm_encrypted(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_encrypted", value)

    @property
    @pulumi.getter(name="mdmEnrolled")
    def mdm_enrolled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Enrolled
        """
        return pulumi.get(self, "mdm_enrolled")

    @mdm_enrolled.setter
    def mdm_enrolled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_enrolled", value)

    @property
    @pulumi.getter(name="mdmImei")
    def mdm_imei(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm IMEI
        """
        return pulumi.get(self, "mdm_imei")

    @mdm_imei.setter
    def mdm_imei(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_imei", value)

    @property
    @pulumi.getter(name="mdmJailBroken")
    def mdm_jail_broken(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm JailBroken
        """
        return pulumi.get(self, "mdm_jail_broken")

    @mdm_jail_broken.setter
    def mdm_jail_broken(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_jail_broken", value)

    @property
    @pulumi.getter(name="mdmManufacturer")
    def mdm_manufacturer(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm Manufacturer
        """
        return pulumi.get(self, "mdm_manufacturer")

    @mdm_manufacturer.setter
    def mdm_manufacturer(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_manufacturer", value)

    @property
    @pulumi.getter(name="mdmModel")
    def mdm_model(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm Model
        """
        return pulumi.get(self, "mdm_model")

    @mdm_model.setter
    def mdm_model(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_model", value)

    @property
    @pulumi.getter(name="mdmOs")
    def mdm_os(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm OS
        """
        return pulumi.get(self, "mdm_os")

    @mdm_os.setter
    def mdm_os(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_os", value)

    @property
    @pulumi.getter(name="mdmPhoneNumber")
    def mdm_phone_number(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm PhoneNumber
        """
        return pulumi.get(self, "mdm_phone_number")

    @mdm_phone_number.setter
    def mdm_phone_number(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_phone_number", value)

    @property
    @pulumi.getter(name="mdmPinlock")
    def mdm_pinlock(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Pinlock
        """
        return pulumi.get(self, "mdm_pinlock")

    @mdm_pinlock.setter
    def mdm_pinlock(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_pinlock", value)

    @property
    @pulumi.getter(name="mdmReachable")
    def mdm_reachable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Reachable
        """
        return pulumi.get(self, "mdm_reachable")

    @mdm_reachable.setter
    def mdm_reachable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_reachable", value)

    @property
    @pulumi.getter(name="mdmSerial")
    def mdm_serial(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm Serial
        """
        return pulumi.get(self, "mdm_serial")

    @mdm_serial.setter
    def mdm_serial(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_serial", value)

    @property
    @pulumi.getter(name="mdmServerName")
    def mdm_server_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm Server Name
        """
        return pulumi.get(self, "mdm_server_name")

    @mdm_server_name.setter
    def mdm_server_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_server_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the endpoint
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="portalUser")
    def portal_user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Portal User
        """
        return pulumi.get(self, "portal_user")

    @portal_user.setter
    def portal_user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "portal_user", value)

    @property
    @pulumi.getter(name="profileId")
    def profile_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Profile ID
        """
        return pulumi.get(self, "profile_id")

    @profile_id.setter
    def profile_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "profile_id", value)

    @property
    @pulumi.getter(name="staticGroupAssignmentDefined")
    def static_group_assignment_defined(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        staticGroupAssignmentDefined - Default value: `true`
        """
        return pulumi.get(self, "static_group_assignment_defined")

    @static_group_assignment_defined.setter
    def static_group_assignment_defined(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "static_group_assignment_defined", value)

    @property
    @pulumi.getter(name="staticProfileAssignmentDefined")
    def static_profile_assignment_defined(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Static Profile Assignment Defined - Default value: `true`
        """
        return pulumi.get(self, "static_profile_assignment_defined")

    @static_profile_assignment_defined.setter
    def static_profile_assignment_defined(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "static_profile_assignment_defined", value)


@pulumi.input_type
class _EndpointState:
    def __init__(__self__, *,
                 custom_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 identity_store: Optional[pulumi.Input[builtins.str]] = None,
                 identity_store_id: Optional[pulumi.Input[builtins.str]] = None,
                 mac: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_compliance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_enrolled: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_imei: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_jail_broken: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_manufacturer: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_model: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_os: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_phone_number: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_pinlock: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_reachable: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_serial: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_server_name: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 portal_user: Optional[pulumi.Input[builtins.str]] = None,
                 profile_id: Optional[pulumi.Input[builtins.str]] = None,
                 static_group_assignment: Optional[pulumi.Input[builtins.bool]] = None,
                 static_group_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None,
                 static_profile_assignment: Optional[pulumi.Input[builtins.bool]] = None,
                 static_profile_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Endpoint resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] custom_attributes: Custom Attributes
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] group_id: Identity Group ID
        :param pulumi.Input[builtins.str] identity_store: Identity Store
        :param pulumi.Input[builtins.str] identity_store_id: Identity Store Id
        :param pulumi.Input[builtins.str] mac: MAC address of the endpoint
        :param pulumi.Input[builtins.bool] mdm_compliance_status: Mdm Compliance Status
        :param pulumi.Input[builtins.bool] mdm_encrypted: Mdm Encrypted
        :param pulumi.Input[builtins.bool] mdm_enrolled: Mdm Enrolled
        :param pulumi.Input[builtins.str] mdm_imei: Mdm IMEI
        :param pulumi.Input[builtins.bool] mdm_jail_broken: Mdm JailBroken
        :param pulumi.Input[builtins.str] mdm_manufacturer: Mdm Manufacturer
        :param pulumi.Input[builtins.str] mdm_model: Mdm Model
        :param pulumi.Input[builtins.str] mdm_os: Mdm OS
        :param pulumi.Input[builtins.str] mdm_phone_number: Mdm PhoneNumber
        :param pulumi.Input[builtins.bool] mdm_pinlock: Mdm Pinlock
        :param pulumi.Input[builtins.bool] mdm_reachable: Mdm Reachable
        :param pulumi.Input[builtins.str] mdm_serial: Mdm Serial
        :param pulumi.Input[builtins.str] mdm_server_name: Mdm Server Name
        :param pulumi.Input[builtins.str] name: The name of the endpoint
        :param pulumi.Input[builtins.str] portal_user: Portal User
        :param pulumi.Input[builtins.str] profile_id: Profile ID
        :param pulumi.Input[builtins.bool] static_group_assignment: Static Group Assignment
        :param pulumi.Input[builtins.bool] static_group_assignment_defined: staticGroupAssignmentDefined - Default value: `true`
        :param pulumi.Input[builtins.bool] static_profile_assignment: Static Profile Assignment
        :param pulumi.Input[builtins.bool] static_profile_assignment_defined: Static Profile Assignment Defined - Default value: `true`
        """
        if custom_attributes is not None:
            pulumi.set(__self__, "custom_attributes", custom_attributes)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if identity_store is not None:
            pulumi.set(__self__, "identity_store", identity_store)
        if identity_store_id is not None:
            pulumi.set(__self__, "identity_store_id", identity_store_id)
        if mac is not None:
            pulumi.set(__self__, "mac", mac)
        if mdm_compliance_status is not None:
            pulumi.set(__self__, "mdm_compliance_status", mdm_compliance_status)
        if mdm_encrypted is not None:
            pulumi.set(__self__, "mdm_encrypted", mdm_encrypted)
        if mdm_enrolled is not None:
            pulumi.set(__self__, "mdm_enrolled", mdm_enrolled)
        if mdm_imei is not None:
            pulumi.set(__self__, "mdm_imei", mdm_imei)
        if mdm_jail_broken is not None:
            pulumi.set(__self__, "mdm_jail_broken", mdm_jail_broken)
        if mdm_manufacturer is not None:
            pulumi.set(__self__, "mdm_manufacturer", mdm_manufacturer)
        if mdm_model is not None:
            pulumi.set(__self__, "mdm_model", mdm_model)
        if mdm_os is not None:
            pulumi.set(__self__, "mdm_os", mdm_os)
        if mdm_phone_number is not None:
            pulumi.set(__self__, "mdm_phone_number", mdm_phone_number)
        if mdm_pinlock is not None:
            pulumi.set(__self__, "mdm_pinlock", mdm_pinlock)
        if mdm_reachable is not None:
            pulumi.set(__self__, "mdm_reachable", mdm_reachable)
        if mdm_serial is not None:
            pulumi.set(__self__, "mdm_serial", mdm_serial)
        if mdm_server_name is not None:
            pulumi.set(__self__, "mdm_server_name", mdm_server_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if portal_user is not None:
            pulumi.set(__self__, "portal_user", portal_user)
        if profile_id is not None:
            pulumi.set(__self__, "profile_id", profile_id)
        if static_group_assignment is not None:
            pulumi.set(__self__, "static_group_assignment", static_group_assignment)
        if static_group_assignment_defined is not None:
            pulumi.set(__self__, "static_group_assignment_defined", static_group_assignment_defined)
        if static_profile_assignment is not None:
            pulumi.set(__self__, "static_profile_assignment", static_profile_assignment)
        if static_profile_assignment_defined is not None:
            pulumi.set(__self__, "static_profile_assignment_defined", static_profile_assignment_defined)

    @property
    @pulumi.getter(name="customAttributes")
    def custom_attributes(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Custom Attributes
        """
        return pulumi.get(self, "custom_attributes")

    @custom_attributes.setter
    def custom_attributes(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "custom_attributes", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identity Group ID
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="identityStore")
    def identity_store(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identity Store
        """
        return pulumi.get(self, "identity_store")

    @identity_store.setter
    def identity_store(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "identity_store", value)

    @property
    @pulumi.getter(name="identityStoreId")
    def identity_store_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identity Store Id
        """
        return pulumi.get(self, "identity_store_id")

    @identity_store_id.setter
    def identity_store_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "identity_store_id", value)

    @property
    @pulumi.getter
    def mac(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        MAC address of the endpoint
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mac", value)

    @property
    @pulumi.getter(name="mdmComplianceStatus")
    def mdm_compliance_status(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Compliance Status
        """
        return pulumi.get(self, "mdm_compliance_status")

    @mdm_compliance_status.setter
    def mdm_compliance_status(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_compliance_status", value)

    @property
    @pulumi.getter(name="mdmEncrypted")
    def mdm_encrypted(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Encrypted
        """
        return pulumi.get(self, "mdm_encrypted")

    @mdm_encrypted.setter
    def mdm_encrypted(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_encrypted", value)

    @property
    @pulumi.getter(name="mdmEnrolled")
    def mdm_enrolled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Enrolled
        """
        return pulumi.get(self, "mdm_enrolled")

    @mdm_enrolled.setter
    def mdm_enrolled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_enrolled", value)

    @property
    @pulumi.getter(name="mdmImei")
    def mdm_imei(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm IMEI
        """
        return pulumi.get(self, "mdm_imei")

    @mdm_imei.setter
    def mdm_imei(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_imei", value)

    @property
    @pulumi.getter(name="mdmJailBroken")
    def mdm_jail_broken(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm JailBroken
        """
        return pulumi.get(self, "mdm_jail_broken")

    @mdm_jail_broken.setter
    def mdm_jail_broken(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_jail_broken", value)

    @property
    @pulumi.getter(name="mdmManufacturer")
    def mdm_manufacturer(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm Manufacturer
        """
        return pulumi.get(self, "mdm_manufacturer")

    @mdm_manufacturer.setter
    def mdm_manufacturer(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_manufacturer", value)

    @property
    @pulumi.getter(name="mdmModel")
    def mdm_model(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm Model
        """
        return pulumi.get(self, "mdm_model")

    @mdm_model.setter
    def mdm_model(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_model", value)

    @property
    @pulumi.getter(name="mdmOs")
    def mdm_os(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm OS
        """
        return pulumi.get(self, "mdm_os")

    @mdm_os.setter
    def mdm_os(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_os", value)

    @property
    @pulumi.getter(name="mdmPhoneNumber")
    def mdm_phone_number(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm PhoneNumber
        """
        return pulumi.get(self, "mdm_phone_number")

    @mdm_phone_number.setter
    def mdm_phone_number(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_phone_number", value)

    @property
    @pulumi.getter(name="mdmPinlock")
    def mdm_pinlock(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Pinlock
        """
        return pulumi.get(self, "mdm_pinlock")

    @mdm_pinlock.setter
    def mdm_pinlock(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_pinlock", value)

    @property
    @pulumi.getter(name="mdmReachable")
    def mdm_reachable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Mdm Reachable
        """
        return pulumi.get(self, "mdm_reachable")

    @mdm_reachable.setter
    def mdm_reachable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "mdm_reachable", value)

    @property
    @pulumi.getter(name="mdmSerial")
    def mdm_serial(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm Serial
        """
        return pulumi.get(self, "mdm_serial")

    @mdm_serial.setter
    def mdm_serial(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_serial", value)

    @property
    @pulumi.getter(name="mdmServerName")
    def mdm_server_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mdm Server Name
        """
        return pulumi.get(self, "mdm_server_name")

    @mdm_server_name.setter
    def mdm_server_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mdm_server_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the endpoint
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="portalUser")
    def portal_user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Portal User
        """
        return pulumi.get(self, "portal_user")

    @portal_user.setter
    def portal_user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "portal_user", value)

    @property
    @pulumi.getter(name="profileId")
    def profile_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Profile ID
        """
        return pulumi.get(self, "profile_id")

    @profile_id.setter
    def profile_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "profile_id", value)

    @property
    @pulumi.getter(name="staticGroupAssignment")
    def static_group_assignment(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Static Group Assignment
        """
        return pulumi.get(self, "static_group_assignment")

    @static_group_assignment.setter
    def static_group_assignment(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "static_group_assignment", value)

    @property
    @pulumi.getter(name="staticGroupAssignmentDefined")
    def static_group_assignment_defined(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        staticGroupAssignmentDefined - Default value: `true`
        """
        return pulumi.get(self, "static_group_assignment_defined")

    @static_group_assignment_defined.setter
    def static_group_assignment_defined(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "static_group_assignment_defined", value)

    @property
    @pulumi.getter(name="staticProfileAssignment")
    def static_profile_assignment(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Static Profile Assignment
        """
        return pulumi.get(self, "static_profile_assignment")

    @static_profile_assignment.setter
    def static_profile_assignment(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "static_profile_assignment", value)

    @property
    @pulumi.getter(name="staticProfileAssignmentDefined")
    def static_profile_assignment_defined(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Static Profile Assignment Defined - Default value: `true`
        """
        return pulumi.get(self, "static_profile_assignment_defined")

    @static_profile_assignment_defined.setter
    def static_profile_assignment_defined(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "static_profile_assignment_defined", value)


class Endpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 identity_store: Optional[pulumi.Input[builtins.str]] = None,
                 identity_store_id: Optional[pulumi.Input[builtins.str]] = None,
                 mac: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_compliance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_enrolled: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_imei: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_jail_broken: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_manufacturer: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_model: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_os: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_phone_number: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_pinlock: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_reachable: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_serial: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_server_name: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 portal_user: Optional[pulumi.Input[builtins.str]] = None,
                 profile_id: Optional[pulumi.Input[builtins.str]] = None,
                 static_group_assignment: Optional[pulumi.Input[builtins.bool]] = None,
                 static_group_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None,
                 static_profile_assignment: Optional[pulumi.Input[builtins.bool]] = None,
                 static_profile_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        This resource can manage an Endpoint.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.Endpoint("example",
            name="00:11:22:33:44:55",
            description="My endpoint",
            mac="00:11:22:33:44:55",
            group_id="3a88eec0-8c00-11e6-996c-525400b48521",
            profile_id="3a91a150-8c00-11e6-996c-525400b48521",
            static_profile_assignment=True,
            static_profile_assignment_defined=True,
            static_group_assignment=True,
            static_group_assignment_defined=True)
        ```

        ## Import

        ```sh
        $ pulumi import ise:identitymanagement/endpoint:Endpoint example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] custom_attributes: Custom Attributes
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] group_id: Identity Group ID
        :param pulumi.Input[builtins.str] identity_store: Identity Store
        :param pulumi.Input[builtins.str] identity_store_id: Identity Store Id
        :param pulumi.Input[builtins.str] mac: MAC address of the endpoint
        :param pulumi.Input[builtins.bool] mdm_compliance_status: Mdm Compliance Status
        :param pulumi.Input[builtins.bool] mdm_encrypted: Mdm Encrypted
        :param pulumi.Input[builtins.bool] mdm_enrolled: Mdm Enrolled
        :param pulumi.Input[builtins.str] mdm_imei: Mdm IMEI
        :param pulumi.Input[builtins.bool] mdm_jail_broken: Mdm JailBroken
        :param pulumi.Input[builtins.str] mdm_manufacturer: Mdm Manufacturer
        :param pulumi.Input[builtins.str] mdm_model: Mdm Model
        :param pulumi.Input[builtins.str] mdm_os: Mdm OS
        :param pulumi.Input[builtins.str] mdm_phone_number: Mdm PhoneNumber
        :param pulumi.Input[builtins.bool] mdm_pinlock: Mdm Pinlock
        :param pulumi.Input[builtins.bool] mdm_reachable: Mdm Reachable
        :param pulumi.Input[builtins.str] mdm_serial: Mdm Serial
        :param pulumi.Input[builtins.str] mdm_server_name: Mdm Server Name
        :param pulumi.Input[builtins.str] name: The name of the endpoint
        :param pulumi.Input[builtins.str] portal_user: Portal User
        :param pulumi.Input[builtins.str] profile_id: Profile ID
        :param pulumi.Input[builtins.bool] static_group_assignment: Static Group Assignment
        :param pulumi.Input[builtins.bool] static_group_assignment_defined: staticGroupAssignmentDefined - Default value: `true`
        :param pulumi.Input[builtins.bool] static_profile_assignment: Static Profile Assignment
        :param pulumi.Input[builtins.bool] static_profile_assignment_defined: Static Profile Assignment Defined - Default value: `true`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage an Endpoint.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.Endpoint("example",
            name="00:11:22:33:44:55",
            description="My endpoint",
            mac="00:11:22:33:44:55",
            group_id="3a88eec0-8c00-11e6-996c-525400b48521",
            profile_id="3a91a150-8c00-11e6-996c-525400b48521",
            static_profile_assignment=True,
            static_profile_assignment_defined=True,
            static_group_assignment=True,
            static_group_assignment_defined=True)
        ```

        ## Import

        ```sh
        $ pulumi import ise:identitymanagement/endpoint:Endpoint example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param EndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 identity_store: Optional[pulumi.Input[builtins.str]] = None,
                 identity_store_id: Optional[pulumi.Input[builtins.str]] = None,
                 mac: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_compliance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_enrolled: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_imei: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_jail_broken: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_manufacturer: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_model: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_os: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_phone_number: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_pinlock: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_reachable: Optional[pulumi.Input[builtins.bool]] = None,
                 mdm_serial: Optional[pulumi.Input[builtins.str]] = None,
                 mdm_server_name: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 portal_user: Optional[pulumi.Input[builtins.str]] = None,
                 profile_id: Optional[pulumi.Input[builtins.str]] = None,
                 static_group_assignment: Optional[pulumi.Input[builtins.bool]] = None,
                 static_group_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None,
                 static_profile_assignment: Optional[pulumi.Input[builtins.bool]] = None,
                 static_profile_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointArgs.__new__(EndpointArgs)

            __props__.__dict__["custom_attributes"] = custom_attributes
            __props__.__dict__["description"] = description
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["identity_store"] = identity_store
            __props__.__dict__["identity_store_id"] = identity_store_id
            if mac is None and not opts.urn:
                raise TypeError("Missing required property 'mac'")
            __props__.__dict__["mac"] = mac
            __props__.__dict__["mdm_compliance_status"] = mdm_compliance_status
            __props__.__dict__["mdm_encrypted"] = mdm_encrypted
            __props__.__dict__["mdm_enrolled"] = mdm_enrolled
            __props__.__dict__["mdm_imei"] = mdm_imei
            __props__.__dict__["mdm_jail_broken"] = mdm_jail_broken
            __props__.__dict__["mdm_manufacturer"] = mdm_manufacturer
            __props__.__dict__["mdm_model"] = mdm_model
            __props__.__dict__["mdm_os"] = mdm_os
            __props__.__dict__["mdm_phone_number"] = mdm_phone_number
            __props__.__dict__["mdm_pinlock"] = mdm_pinlock
            __props__.__dict__["mdm_reachable"] = mdm_reachable
            __props__.__dict__["mdm_serial"] = mdm_serial
            __props__.__dict__["mdm_server_name"] = mdm_server_name
            __props__.__dict__["name"] = name
            __props__.__dict__["portal_user"] = portal_user
            __props__.__dict__["profile_id"] = profile_id
            if static_group_assignment is None and not opts.urn:
                raise TypeError("Missing required property 'static_group_assignment'")
            __props__.__dict__["static_group_assignment"] = static_group_assignment
            __props__.__dict__["static_group_assignment_defined"] = static_group_assignment_defined
            if static_profile_assignment is None and not opts.urn:
                raise TypeError("Missing required property 'static_profile_assignment'")
            __props__.__dict__["static_profile_assignment"] = static_profile_assignment
            __props__.__dict__["static_profile_assignment_defined"] = static_profile_assignment_defined
        super(Endpoint, __self__).__init__(
            'ise:identitymanagement/endpoint:Endpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            custom_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            group_id: Optional[pulumi.Input[builtins.str]] = None,
            identity_store: Optional[pulumi.Input[builtins.str]] = None,
            identity_store_id: Optional[pulumi.Input[builtins.str]] = None,
            mac: Optional[pulumi.Input[builtins.str]] = None,
            mdm_compliance_status: Optional[pulumi.Input[builtins.bool]] = None,
            mdm_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
            mdm_enrolled: Optional[pulumi.Input[builtins.bool]] = None,
            mdm_imei: Optional[pulumi.Input[builtins.str]] = None,
            mdm_jail_broken: Optional[pulumi.Input[builtins.bool]] = None,
            mdm_manufacturer: Optional[pulumi.Input[builtins.str]] = None,
            mdm_model: Optional[pulumi.Input[builtins.str]] = None,
            mdm_os: Optional[pulumi.Input[builtins.str]] = None,
            mdm_phone_number: Optional[pulumi.Input[builtins.str]] = None,
            mdm_pinlock: Optional[pulumi.Input[builtins.bool]] = None,
            mdm_reachable: Optional[pulumi.Input[builtins.bool]] = None,
            mdm_serial: Optional[pulumi.Input[builtins.str]] = None,
            mdm_server_name: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            portal_user: Optional[pulumi.Input[builtins.str]] = None,
            profile_id: Optional[pulumi.Input[builtins.str]] = None,
            static_group_assignment: Optional[pulumi.Input[builtins.bool]] = None,
            static_group_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None,
            static_profile_assignment: Optional[pulumi.Input[builtins.bool]] = None,
            static_profile_assignment_defined: Optional[pulumi.Input[builtins.bool]] = None) -> 'Endpoint':
        """
        Get an existing Endpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] custom_attributes: Custom Attributes
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] group_id: Identity Group ID
        :param pulumi.Input[builtins.str] identity_store: Identity Store
        :param pulumi.Input[builtins.str] identity_store_id: Identity Store Id
        :param pulumi.Input[builtins.str] mac: MAC address of the endpoint
        :param pulumi.Input[builtins.bool] mdm_compliance_status: Mdm Compliance Status
        :param pulumi.Input[builtins.bool] mdm_encrypted: Mdm Encrypted
        :param pulumi.Input[builtins.bool] mdm_enrolled: Mdm Enrolled
        :param pulumi.Input[builtins.str] mdm_imei: Mdm IMEI
        :param pulumi.Input[builtins.bool] mdm_jail_broken: Mdm JailBroken
        :param pulumi.Input[builtins.str] mdm_manufacturer: Mdm Manufacturer
        :param pulumi.Input[builtins.str] mdm_model: Mdm Model
        :param pulumi.Input[builtins.str] mdm_os: Mdm OS
        :param pulumi.Input[builtins.str] mdm_phone_number: Mdm PhoneNumber
        :param pulumi.Input[builtins.bool] mdm_pinlock: Mdm Pinlock
        :param pulumi.Input[builtins.bool] mdm_reachable: Mdm Reachable
        :param pulumi.Input[builtins.str] mdm_serial: Mdm Serial
        :param pulumi.Input[builtins.str] mdm_server_name: Mdm Server Name
        :param pulumi.Input[builtins.str] name: The name of the endpoint
        :param pulumi.Input[builtins.str] portal_user: Portal User
        :param pulumi.Input[builtins.str] profile_id: Profile ID
        :param pulumi.Input[builtins.bool] static_group_assignment: Static Group Assignment
        :param pulumi.Input[builtins.bool] static_group_assignment_defined: staticGroupAssignmentDefined - Default value: `true`
        :param pulumi.Input[builtins.bool] static_profile_assignment: Static Profile Assignment
        :param pulumi.Input[builtins.bool] static_profile_assignment_defined: Static Profile Assignment Defined - Default value: `true`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointState.__new__(_EndpointState)

        __props__.__dict__["custom_attributes"] = custom_attributes
        __props__.__dict__["description"] = description
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["identity_store"] = identity_store
        __props__.__dict__["identity_store_id"] = identity_store_id
        __props__.__dict__["mac"] = mac
        __props__.__dict__["mdm_compliance_status"] = mdm_compliance_status
        __props__.__dict__["mdm_encrypted"] = mdm_encrypted
        __props__.__dict__["mdm_enrolled"] = mdm_enrolled
        __props__.__dict__["mdm_imei"] = mdm_imei
        __props__.__dict__["mdm_jail_broken"] = mdm_jail_broken
        __props__.__dict__["mdm_manufacturer"] = mdm_manufacturer
        __props__.__dict__["mdm_model"] = mdm_model
        __props__.__dict__["mdm_os"] = mdm_os
        __props__.__dict__["mdm_phone_number"] = mdm_phone_number
        __props__.__dict__["mdm_pinlock"] = mdm_pinlock
        __props__.__dict__["mdm_reachable"] = mdm_reachable
        __props__.__dict__["mdm_serial"] = mdm_serial
        __props__.__dict__["mdm_server_name"] = mdm_server_name
        __props__.__dict__["name"] = name
        __props__.__dict__["portal_user"] = portal_user
        __props__.__dict__["profile_id"] = profile_id
        __props__.__dict__["static_group_assignment"] = static_group_assignment
        __props__.__dict__["static_group_assignment_defined"] = static_group_assignment_defined
        __props__.__dict__["static_profile_assignment"] = static_profile_assignment
        __props__.__dict__["static_profile_assignment_defined"] = static_profile_assignment_defined
        return Endpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="customAttributes")
    def custom_attributes(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Custom Attributes
        """
        return pulumi.get(self, "custom_attributes")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Identity Group ID
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="identityStore")
    def identity_store(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Identity Store
        """
        return pulumi.get(self, "identity_store")

    @property
    @pulumi.getter(name="identityStoreId")
    def identity_store_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Identity Store Id
        """
        return pulumi.get(self, "identity_store_id")

    @property
    @pulumi.getter
    def mac(self) -> pulumi.Output[builtins.str]:
        """
        MAC address of the endpoint
        """
        return pulumi.get(self, "mac")

    @property
    @pulumi.getter(name="mdmComplianceStatus")
    def mdm_compliance_status(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Mdm Compliance Status
        """
        return pulumi.get(self, "mdm_compliance_status")

    @property
    @pulumi.getter(name="mdmEncrypted")
    def mdm_encrypted(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Mdm Encrypted
        """
        return pulumi.get(self, "mdm_encrypted")

    @property
    @pulumi.getter(name="mdmEnrolled")
    def mdm_enrolled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Mdm Enrolled
        """
        return pulumi.get(self, "mdm_enrolled")

    @property
    @pulumi.getter(name="mdmImei")
    def mdm_imei(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Mdm IMEI
        """
        return pulumi.get(self, "mdm_imei")

    @property
    @pulumi.getter(name="mdmJailBroken")
    def mdm_jail_broken(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Mdm JailBroken
        """
        return pulumi.get(self, "mdm_jail_broken")

    @property
    @pulumi.getter(name="mdmManufacturer")
    def mdm_manufacturer(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Mdm Manufacturer
        """
        return pulumi.get(self, "mdm_manufacturer")

    @property
    @pulumi.getter(name="mdmModel")
    def mdm_model(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Mdm Model
        """
        return pulumi.get(self, "mdm_model")

    @property
    @pulumi.getter(name="mdmOs")
    def mdm_os(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Mdm OS
        """
        return pulumi.get(self, "mdm_os")

    @property
    @pulumi.getter(name="mdmPhoneNumber")
    def mdm_phone_number(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Mdm PhoneNumber
        """
        return pulumi.get(self, "mdm_phone_number")

    @property
    @pulumi.getter(name="mdmPinlock")
    def mdm_pinlock(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Mdm Pinlock
        """
        return pulumi.get(self, "mdm_pinlock")

    @property
    @pulumi.getter(name="mdmReachable")
    def mdm_reachable(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Mdm Reachable
        """
        return pulumi.get(self, "mdm_reachable")

    @property
    @pulumi.getter(name="mdmSerial")
    def mdm_serial(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Mdm Serial
        """
        return pulumi.get(self, "mdm_serial")

    @property
    @pulumi.getter(name="mdmServerName")
    def mdm_server_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Mdm Server Name
        """
        return pulumi.get(self, "mdm_server_name")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the endpoint
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="portalUser")
    def portal_user(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Portal User
        """
        return pulumi.get(self, "portal_user")

    @property
    @pulumi.getter(name="profileId")
    def profile_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Profile ID
        """
        return pulumi.get(self, "profile_id")

    @property
    @pulumi.getter(name="staticGroupAssignment")
    def static_group_assignment(self) -> pulumi.Output[builtins.bool]:
        """
        Static Group Assignment
        """
        return pulumi.get(self, "static_group_assignment")

    @property
    @pulumi.getter(name="staticGroupAssignmentDefined")
    def static_group_assignment_defined(self) -> pulumi.Output[builtins.bool]:
        """
        staticGroupAssignmentDefined - Default value: `true`
        """
        return pulumi.get(self, "static_group_assignment_defined")

    @property
    @pulumi.getter(name="staticProfileAssignment")
    def static_profile_assignment(self) -> pulumi.Output[builtins.bool]:
        """
        Static Profile Assignment
        """
        return pulumi.get(self, "static_profile_assignment")

    @property
    @pulumi.getter(name="staticProfileAssignmentDefined")
    def static_profile_assignment_defined(self) -> pulumi.Output[builtins.bool]:
        """
        Static Profile Assignment Defined - Default value: `true`
        """
        return pulumi.get(self, "static_profile_assignment_defined")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIdentitySourceSequenceResult',
    'AwaitableGetIdentitySourceSequenceResult',
    'get_identity_source_sequence',
    'get_identity_source_sequence_output',
]

@pulumi.output_type
class GetIdentitySourceSequenceResult:
    """
    A collection of values returned by getIdentitySourceSequence.
    """
    def __init__(__self__, break_on_store_fail=None, certificate_authentication_profile=None, description=None, id=None, identity_sources=None, name=None):
        if break_on_store_fail and not isinstance(break_on_store_fail, bool):
            raise TypeError("Expected argument 'break_on_store_fail' to be a bool")
        pulumi.set(__self__, "break_on_store_fail", break_on_store_fail)
        if certificate_authentication_profile and not isinstance(certificate_authentication_profile, str):
            raise TypeError("Expected argument 'certificate_authentication_profile' to be a str")
        pulumi.set(__self__, "certificate_authentication_profile", certificate_authentication_profile)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identity_sources and not isinstance(identity_sources, list):
            raise TypeError("Expected argument 'identity_sources' to be a list")
        pulumi.set(__self__, "identity_sources", identity_sources)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="breakOnStoreFail")
    def break_on_store_fail(self) -> builtins.bool:
        """
        Do not access other stores in the sequence if a selected identity store cannot be accessed for authentication
        """
        return pulumi.get(self, "break_on_store_fail")

    @property
    @pulumi.getter(name="certificateAuthenticationProfile")
    def certificate_authentication_profile(self) -> builtins.str:
        """
        Certificate Authentication Profile, empty if doesn't exist
        """
        return pulumi.get(self, "certificate_authentication_profile")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="identitySources")
    def identity_sources(self) -> Sequence['outputs.GetIdentitySourceSequenceIdentitySourceResult']:
        return pulumi.get(self, "identity_sources")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the identity source sequence
        """
        return pulumi.get(self, "name")


class AwaitableGetIdentitySourceSequenceResult(GetIdentitySourceSequenceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdentitySourceSequenceResult(
            break_on_store_fail=self.break_on_store_fail,
            certificate_authentication_profile=self.certificate_authentication_profile,
            description=self.description,
            id=self.id,
            identity_sources=self.identity_sources,
            name=self.name)


def get_identity_source_sequence(id: Optional[builtins.str] = None,
                                 name: Optional[builtins.str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdentitySourceSequenceResult:
    """
    This data source can read the Identity Source Sequence.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_identity_source_sequence(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the identity source sequence
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getIdentitySourceSequence:getIdentitySourceSequence', __args__, opts=opts, typ=GetIdentitySourceSequenceResult).value

    return AwaitableGetIdentitySourceSequenceResult(
        break_on_store_fail=pulumi.get(__ret__, 'break_on_store_fail'),
        certificate_authentication_profile=pulumi.get(__ret__, 'certificate_authentication_profile'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identity_sources=pulumi.get(__ret__, 'identity_sources'),
        name=pulumi.get(__ret__, 'name'))
def get_identity_source_sequence_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                        name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdentitySourceSequenceResult]:
    """
    This data source can read the Identity Source Sequence.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_identity_source_sequence(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the identity source sequence
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getIdentitySourceSequence:getIdentitySourceSequence', __args__, opts=opts, typ=GetIdentitySourceSequenceResult)
    return __ret__.apply(lambda __response__: GetIdentitySourceSequenceResult(
        break_on_store_fail=pulumi.get(__response__, 'break_on_store_fail'),
        certificate_authentication_profile=pulumi.get(__response__, 'certificate_authentication_profile'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identity_sources=pulumi.get(__response__, 'identity_sources'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAuthorizationProfileResult',
    'AwaitableGetAuthorizationProfileResult',
    'get_authorization_profile',
    'get_authorization_profile_output',
]

@pulumi.output_type
class GetAuthorizationProfileResult:
    """
    A collection of values returned by getAuthorizationProfile.
    """
    def __init__(__self__, access_type=None, acl=None, advanced_attributes=None, agentless_posture=None, airespace_acl=None, airespace_ipv6_acl=None, asa_vpn=None, auto_smart_port=None, avc_profile=None, dacl_name=None, description=None, easywired_session_candidate=None, id=None, interface_template=None, ipv6_acl_filter=None, ipv6_dacl_name=None, mac_sec_policy=None, name=None, neat=None, profile_name=None, reauthentication_connectivity=None, reauthentication_timer=None, service_template=None, track_movement=None, unique_identifier=None, vlan_name_id=None, vlan_tag_id=None, voice_domain_permission=None, web_auth=None, web_redirection_acl=None, web_redirection_display_certificates_renewal_messages=None, web_redirection_portal_name=None, web_redirection_static_ip_host_name_fqdn=None, web_redirection_type=None):
        if access_type and not isinstance(access_type, str):
            raise TypeError("Expected argument 'access_type' to be a str")
        pulumi.set(__self__, "access_type", access_type)
        if acl and not isinstance(acl, str):
            raise TypeError("Expected argument 'acl' to be a str")
        pulumi.set(__self__, "acl", acl)
        if advanced_attributes and not isinstance(advanced_attributes, list):
            raise TypeError("Expected argument 'advanced_attributes' to be a list")
        pulumi.set(__self__, "advanced_attributes", advanced_attributes)
        if agentless_posture and not isinstance(agentless_posture, bool):
            raise TypeError("Expected argument 'agentless_posture' to be a bool")
        pulumi.set(__self__, "agentless_posture", agentless_posture)
        if airespace_acl and not isinstance(airespace_acl, str):
            raise TypeError("Expected argument 'airespace_acl' to be a str")
        pulumi.set(__self__, "airespace_acl", airespace_acl)
        if airespace_ipv6_acl and not isinstance(airespace_ipv6_acl, str):
            raise TypeError("Expected argument 'airespace_ipv6_acl' to be a str")
        pulumi.set(__self__, "airespace_ipv6_acl", airespace_ipv6_acl)
        if asa_vpn and not isinstance(asa_vpn, str):
            raise TypeError("Expected argument 'asa_vpn' to be a str")
        pulumi.set(__self__, "asa_vpn", asa_vpn)
        if auto_smart_port and not isinstance(auto_smart_port, str):
            raise TypeError("Expected argument 'auto_smart_port' to be a str")
        pulumi.set(__self__, "auto_smart_port", auto_smart_port)
        if avc_profile and not isinstance(avc_profile, str):
            raise TypeError("Expected argument 'avc_profile' to be a str")
        pulumi.set(__self__, "avc_profile", avc_profile)
        if dacl_name and not isinstance(dacl_name, str):
            raise TypeError("Expected argument 'dacl_name' to be a str")
        pulumi.set(__self__, "dacl_name", dacl_name)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if easywired_session_candidate and not isinstance(easywired_session_candidate, bool):
            raise TypeError("Expected argument 'easywired_session_candidate' to be a bool")
        pulumi.set(__self__, "easywired_session_candidate", easywired_session_candidate)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if interface_template and not isinstance(interface_template, str):
            raise TypeError("Expected argument 'interface_template' to be a str")
        pulumi.set(__self__, "interface_template", interface_template)
        if ipv6_acl_filter and not isinstance(ipv6_acl_filter, str):
            raise TypeError("Expected argument 'ipv6_acl_filter' to be a str")
        pulumi.set(__self__, "ipv6_acl_filter", ipv6_acl_filter)
        if ipv6_dacl_name and not isinstance(ipv6_dacl_name, str):
            raise TypeError("Expected argument 'ipv6_dacl_name' to be a str")
        pulumi.set(__self__, "ipv6_dacl_name", ipv6_dacl_name)
        if mac_sec_policy and not isinstance(mac_sec_policy, str):
            raise TypeError("Expected argument 'mac_sec_policy' to be a str")
        pulumi.set(__self__, "mac_sec_policy", mac_sec_policy)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if neat and not isinstance(neat, bool):
            raise TypeError("Expected argument 'neat' to be a bool")
        pulumi.set(__self__, "neat", neat)
        if profile_name and not isinstance(profile_name, str):
            raise TypeError("Expected argument 'profile_name' to be a str")
        pulumi.set(__self__, "profile_name", profile_name)
        if reauthentication_connectivity and not isinstance(reauthentication_connectivity, str):
            raise TypeError("Expected argument 'reauthentication_connectivity' to be a str")
        pulumi.set(__self__, "reauthentication_connectivity", reauthentication_connectivity)
        if reauthentication_timer and not isinstance(reauthentication_timer, int):
            raise TypeError("Expected argument 'reauthentication_timer' to be a int")
        pulumi.set(__self__, "reauthentication_timer", reauthentication_timer)
        if service_template and not isinstance(service_template, bool):
            raise TypeError("Expected argument 'service_template' to be a bool")
        pulumi.set(__self__, "service_template", service_template)
        if track_movement and not isinstance(track_movement, bool):
            raise TypeError("Expected argument 'track_movement' to be a bool")
        pulumi.set(__self__, "track_movement", track_movement)
        if unique_identifier and not isinstance(unique_identifier, str):
            raise TypeError("Expected argument 'unique_identifier' to be a str")
        pulumi.set(__self__, "unique_identifier", unique_identifier)
        if vlan_name_id and not isinstance(vlan_name_id, str):
            raise TypeError("Expected argument 'vlan_name_id' to be a str")
        pulumi.set(__self__, "vlan_name_id", vlan_name_id)
        if vlan_tag_id and not isinstance(vlan_tag_id, int):
            raise TypeError("Expected argument 'vlan_tag_id' to be a int")
        pulumi.set(__self__, "vlan_tag_id", vlan_tag_id)
        if voice_domain_permission and not isinstance(voice_domain_permission, bool):
            raise TypeError("Expected argument 'voice_domain_permission' to be a bool")
        pulumi.set(__self__, "voice_domain_permission", voice_domain_permission)
        if web_auth and not isinstance(web_auth, bool):
            raise TypeError("Expected argument 'web_auth' to be a bool")
        pulumi.set(__self__, "web_auth", web_auth)
        if web_redirection_acl and not isinstance(web_redirection_acl, str):
            raise TypeError("Expected argument 'web_redirection_acl' to be a str")
        pulumi.set(__self__, "web_redirection_acl", web_redirection_acl)
        if web_redirection_display_certificates_renewal_messages and not isinstance(web_redirection_display_certificates_renewal_messages, bool):
            raise TypeError("Expected argument 'web_redirection_display_certificates_renewal_messages' to be a bool")
        pulumi.set(__self__, "web_redirection_display_certificates_renewal_messages", web_redirection_display_certificates_renewal_messages)
        if web_redirection_portal_name and not isinstance(web_redirection_portal_name, str):
            raise TypeError("Expected argument 'web_redirection_portal_name' to be a str")
        pulumi.set(__self__, "web_redirection_portal_name", web_redirection_portal_name)
        if web_redirection_static_ip_host_name_fqdn and not isinstance(web_redirection_static_ip_host_name_fqdn, str):
            raise TypeError("Expected argument 'web_redirection_static_ip_host_name_fqdn' to be a str")
        pulumi.set(__self__, "web_redirection_static_ip_host_name_fqdn", web_redirection_static_ip_host_name_fqdn)
        if web_redirection_type and not isinstance(web_redirection_type, str):
            raise TypeError("Expected argument 'web_redirection_type' to be a str")
        pulumi.set(__self__, "web_redirection_type", web_redirection_type)

    @property
    @pulumi.getter(name="accessType")
    def access_type(self) -> builtins.str:
        """
        Access type
        """
        return pulumi.get(self, "access_type")

    @property
    @pulumi.getter
    def acl(self) -> builtins.str:
        """
        ACL
        """
        return pulumi.get(self, "acl")

    @property
    @pulumi.getter(name="advancedAttributes")
    def advanced_attributes(self) -> Sequence['outputs.GetAuthorizationProfileAdvancedAttributeResult']:
        """
        List of advanced attributes
        """
        return pulumi.get(self, "advanced_attributes")

    @property
    @pulumi.getter(name="agentlessPosture")
    def agentless_posture(self) -> builtins.bool:
        """
        Agentless Posture.
        """
        return pulumi.get(self, "agentless_posture")

    @property
    @pulumi.getter(name="airespaceAcl")
    def airespace_acl(self) -> builtins.str:
        """
        Airespace ACL
        """
        return pulumi.get(self, "airespace_acl")

    @property
    @pulumi.getter(name="airespaceIpv6Acl")
    def airespace_ipv6_acl(self) -> builtins.str:
        """
        Airespace IPv6 ACL
        """
        return pulumi.get(self, "airespace_ipv6_acl")

    @property
    @pulumi.getter(name="asaVpn")
    def asa_vpn(self) -> builtins.str:
        """
        ASA VPN
        """
        return pulumi.get(self, "asa_vpn")

    @property
    @pulumi.getter(name="autoSmartPort")
    def auto_smart_port(self) -> builtins.str:
        """
        Auto smart port
        """
        return pulumi.get(self, "auto_smart_port")

    @property
    @pulumi.getter(name="avcProfile")
    def avc_profile(self) -> builtins.str:
        """
        AVC profile
        """
        return pulumi.get(self, "avc_profile")

    @property
    @pulumi.getter(name="daclName")
    def dacl_name(self) -> builtins.str:
        """
        DACL name
        """
        return pulumi.get(self, "dacl_name")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="easywiredSessionCandidate")
    def easywired_session_candidate(self) -> builtins.bool:
        """
        Easy wired session candidate
        """
        return pulumi.get(self, "easywired_session_candidate")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="interfaceTemplate")
    def interface_template(self) -> builtins.str:
        """
        Interface template
        """
        return pulumi.get(self, "interface_template")

    @property
    @pulumi.getter(name="ipv6AclFilter")
    def ipv6_acl_filter(self) -> builtins.str:
        """
        IPv6 ACL
        """
        return pulumi.get(self, "ipv6_acl_filter")

    @property
    @pulumi.getter(name="ipv6DaclName")
    def ipv6_dacl_name(self) -> builtins.str:
        """
        IPv6 DACL name
        """
        return pulumi.get(self, "ipv6_dacl_name")

    @property
    @pulumi.getter(name="macSecPolicy")
    def mac_sec_policy(self) -> builtins.str:
        """
        MacSec policy
        """
        return pulumi.get(self, "mac_sec_policy")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the authorization profile
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def neat(self) -> builtins.bool:
        """
        NEAT
        """
        return pulumi.get(self, "neat")

    @property
    @pulumi.getter(name="profileName")
    def profile_name(self) -> builtins.str:
        """
        Value needs to be an existing Network Device Profile
        """
        return pulumi.get(self, "profile_name")

    @property
    @pulumi.getter(name="reauthenticationConnectivity")
    def reauthentication_connectivity(self) -> builtins.str:
        """
        Maintain Connectivity During Reauthentication
        """
        return pulumi.get(self, "reauthentication_connectivity")

    @property
    @pulumi.getter(name="reauthenticationTimer")
    def reauthentication_timer(self) -> builtins.int:
        """
        Reauthentication timer
        """
        return pulumi.get(self, "reauthentication_timer")

    @property
    @pulumi.getter(name="serviceTemplate")
    def service_template(self) -> builtins.bool:
        """
        Service template
        """
        return pulumi.get(self, "service_template")

    @property
    @pulumi.getter(name="trackMovement")
    def track_movement(self) -> builtins.bool:
        """
        Track movement
        """
        return pulumi.get(self, "track_movement")

    @property
    @pulumi.getter(name="uniqueIdentifier")
    def unique_identifier(self) -> builtins.str:
        """
        Unique identifier
        """
        return pulumi.get(self, "unique_identifier")

    @property
    @pulumi.getter(name="vlanNameId")
    def vlan_name_id(self) -> builtins.str:
        """
        Vlan name or ID
        """
        return pulumi.get(self, "vlan_name_id")

    @property
    @pulumi.getter(name="vlanTagId")
    def vlan_tag_id(self) -> builtins.int:
        """
        Vlan tag ID
        """
        return pulumi.get(self, "vlan_tag_id")

    @property
    @pulumi.getter(name="voiceDomainPermission")
    def voice_domain_permission(self) -> builtins.bool:
        """
        Voice domain permission
        """
        return pulumi.get(self, "voice_domain_permission")

    @property
    @pulumi.getter(name="webAuth")
    def web_auth(self) -> builtins.bool:
        """
        Web authentication (local)
        """
        return pulumi.get(self, "web_auth")

    @property
    @pulumi.getter(name="webRedirectionAcl")
    def web_redirection_acl(self) -> builtins.str:
        """
        Web redirection ACL
        """
        return pulumi.get(self, "web_redirection_acl")

    @property
    @pulumi.getter(name="webRedirectionDisplayCertificatesRenewalMessages")
    def web_redirection_display_certificates_renewal_messages(self) -> builtins.bool:
        """
        This attribute is mandatory when `web_redirection_type` value is `CentralizedWebAuth`. For all other `web_redirection_type` values the field must be ignored.
        """
        return pulumi.get(self, "web_redirection_display_certificates_renewal_messages")

    @property
    @pulumi.getter(name="webRedirectionPortalName")
    def web_redirection_portal_name(self) -> builtins.str:
        """
        A portal that exist in the DB and fits the `web_redirection_type`
        """
        return pulumi.get(self, "web_redirection_portal_name")

    @property
    @pulumi.getter(name="webRedirectionStaticIpHostNameFqdn")
    def web_redirection_static_ip_host_name_fqdn(self) -> builtins.str:
        """
        IP, hostname or FQDN
        """
        return pulumi.get(self, "web_redirection_static_ip_host_name_fqdn")

    @property
    @pulumi.getter(name="webRedirectionType")
    def web_redirection_type(self) -> builtins.str:
        """
        This type must fit the `web_redirection_portal_name`
        """
        return pulumi.get(self, "web_redirection_type")


class AwaitableGetAuthorizationProfileResult(GetAuthorizationProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthorizationProfileResult(
            access_type=self.access_type,
            acl=self.acl,
            advanced_attributes=self.advanced_attributes,
            agentless_posture=self.agentless_posture,
            airespace_acl=self.airespace_acl,
            airespace_ipv6_acl=self.airespace_ipv6_acl,
            asa_vpn=self.asa_vpn,
            auto_smart_port=self.auto_smart_port,
            avc_profile=self.avc_profile,
            dacl_name=self.dacl_name,
            description=self.description,
            easywired_session_candidate=self.easywired_session_candidate,
            id=self.id,
            interface_template=self.interface_template,
            ipv6_acl_filter=self.ipv6_acl_filter,
            ipv6_dacl_name=self.ipv6_dacl_name,
            mac_sec_policy=self.mac_sec_policy,
            name=self.name,
            neat=self.neat,
            profile_name=self.profile_name,
            reauthentication_connectivity=self.reauthentication_connectivity,
            reauthentication_timer=self.reauthentication_timer,
            service_template=self.service_template,
            track_movement=self.track_movement,
            unique_identifier=self.unique_identifier,
            vlan_name_id=self.vlan_name_id,
            vlan_tag_id=self.vlan_tag_id,
            voice_domain_permission=self.voice_domain_permission,
            web_auth=self.web_auth,
            web_redirection_acl=self.web_redirection_acl,
            web_redirection_display_certificates_renewal_messages=self.web_redirection_display_certificates_renewal_messages,
            web_redirection_portal_name=self.web_redirection_portal_name,
            web_redirection_static_ip_host_name_fqdn=self.web_redirection_static_ip_host_name_fqdn,
            web_redirection_type=self.web_redirection_type)


def get_authorization_profile(id: Optional[builtins.str] = None,
                              name: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthorizationProfileResult:
    """
    This data source can read an authorization profiles policy element.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.networkaccess.get_authorization_profile(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the authorization profile
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:networkaccess/getAuthorizationProfile:getAuthorizationProfile', __args__, opts=opts, typ=GetAuthorizationProfileResult).value

    return AwaitableGetAuthorizationProfileResult(
        access_type=pulumi.get(__ret__, 'access_type'),
        acl=pulumi.get(__ret__, 'acl'),
        advanced_attributes=pulumi.get(__ret__, 'advanced_attributes'),
        agentless_posture=pulumi.get(__ret__, 'agentless_posture'),
        airespace_acl=pulumi.get(__ret__, 'airespace_acl'),
        airespace_ipv6_acl=pulumi.get(__ret__, 'airespace_ipv6_acl'),
        asa_vpn=pulumi.get(__ret__, 'asa_vpn'),
        auto_smart_port=pulumi.get(__ret__, 'auto_smart_port'),
        avc_profile=pulumi.get(__ret__, 'avc_profile'),
        dacl_name=pulumi.get(__ret__, 'dacl_name'),
        description=pulumi.get(__ret__, 'description'),
        easywired_session_candidate=pulumi.get(__ret__, 'easywired_session_candidate'),
        id=pulumi.get(__ret__, 'id'),
        interface_template=pulumi.get(__ret__, 'interface_template'),
        ipv6_acl_filter=pulumi.get(__ret__, 'ipv6_acl_filter'),
        ipv6_dacl_name=pulumi.get(__ret__, 'ipv6_dacl_name'),
        mac_sec_policy=pulumi.get(__ret__, 'mac_sec_policy'),
        name=pulumi.get(__ret__, 'name'),
        neat=pulumi.get(__ret__, 'neat'),
        profile_name=pulumi.get(__ret__, 'profile_name'),
        reauthentication_connectivity=pulumi.get(__ret__, 'reauthentication_connectivity'),
        reauthentication_timer=pulumi.get(__ret__, 'reauthentication_timer'),
        service_template=pulumi.get(__ret__, 'service_template'),
        track_movement=pulumi.get(__ret__, 'track_movement'),
        unique_identifier=pulumi.get(__ret__, 'unique_identifier'),
        vlan_name_id=pulumi.get(__ret__, 'vlan_name_id'),
        vlan_tag_id=pulumi.get(__ret__, 'vlan_tag_id'),
        voice_domain_permission=pulumi.get(__ret__, 'voice_domain_permission'),
        web_auth=pulumi.get(__ret__, 'web_auth'),
        web_redirection_acl=pulumi.get(__ret__, 'web_redirection_acl'),
        web_redirection_display_certificates_renewal_messages=pulumi.get(__ret__, 'web_redirection_display_certificates_renewal_messages'),
        web_redirection_portal_name=pulumi.get(__ret__, 'web_redirection_portal_name'),
        web_redirection_static_ip_host_name_fqdn=pulumi.get(__ret__, 'web_redirection_static_ip_host_name_fqdn'),
        web_redirection_type=pulumi.get(__ret__, 'web_redirection_type'))
def get_authorization_profile_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                     name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAuthorizationProfileResult]:
    """
    This data source can read an authorization profiles policy element.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.networkaccess.get_authorization_profile(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the authorization profile
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:networkaccess/getAuthorizationProfile:getAuthorizationProfile', __args__, opts=opts, typ=GetAuthorizationProfileResult)
    return __ret__.apply(lambda __response__: GetAuthorizationProfileResult(
        access_type=pulumi.get(__response__, 'access_type'),
        acl=pulumi.get(__response__, 'acl'),
        advanced_attributes=pulumi.get(__response__, 'advanced_attributes'),
        agentless_posture=pulumi.get(__response__, 'agentless_posture'),
        airespace_acl=pulumi.get(__response__, 'airespace_acl'),
        airespace_ipv6_acl=pulumi.get(__response__, 'airespace_ipv6_acl'),
        asa_vpn=pulumi.get(__response__, 'asa_vpn'),
        auto_smart_port=pulumi.get(__response__, 'auto_smart_port'),
        avc_profile=pulumi.get(__response__, 'avc_profile'),
        dacl_name=pulumi.get(__response__, 'dacl_name'),
        description=pulumi.get(__response__, 'description'),
        easywired_session_candidate=pulumi.get(__response__, 'easywired_session_candidate'),
        id=pulumi.get(__response__, 'id'),
        interface_template=pulumi.get(__response__, 'interface_template'),
        ipv6_acl_filter=pulumi.get(__response__, 'ipv6_acl_filter'),
        ipv6_dacl_name=pulumi.get(__response__, 'ipv6_dacl_name'),
        mac_sec_policy=pulumi.get(__response__, 'mac_sec_policy'),
        name=pulumi.get(__response__, 'name'),
        neat=pulumi.get(__response__, 'neat'),
        profile_name=pulumi.get(__response__, 'profile_name'),
        reauthentication_connectivity=pulumi.get(__response__, 'reauthentication_connectivity'),
        reauthentication_timer=pulumi.get(__response__, 'reauthentication_timer'),
        service_template=pulumi.get(__response__, 'service_template'),
        track_movement=pulumi.get(__response__, 'track_movement'),
        unique_identifier=pulumi.get(__response__, 'unique_identifier'),
        vlan_name_id=pulumi.get(__response__, 'vlan_name_id'),
        vlan_tag_id=pulumi.get(__response__, 'vlan_tag_id'),
        voice_domain_permission=pulumi.get(__response__, 'voice_domain_permission'),
        web_auth=pulumi.get(__response__, 'web_auth'),
        web_redirection_acl=pulumi.get(__response__, 'web_redirection_acl'),
        web_redirection_display_certificates_renewal_messages=pulumi.get(__response__, 'web_redirection_display_certificates_renewal_messages'),
        web_redirection_portal_name=pulumi.get(__response__, 'web_redirection_portal_name'),
        web_redirection_static_ip_host_name_fqdn=pulumi.get(__response__, 'web_redirection_static_ip_host_name_fqdn'),
        web_redirection_type=pulumi.get(__response__, 'web_redirection_type')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIpToSgtMappingGroupResult',
    'AwaitableGetIpToSgtMappingGroupResult',
    'get_ip_to_sgt_mapping_group',
    'get_ip_to_sgt_mapping_group_output',
]

@pulumi.output_type
class GetIpToSgtMappingGroupResult:
    """
    A collection of values returned by getIpToSgtMappingGroup.
    """
    def __init__(__self__, deploy_to=None, deploy_type=None, description=None, id=None, name=None, sgt=None):
        if deploy_to and not isinstance(deploy_to, str):
            raise TypeError("Expected argument 'deploy_to' to be a str")
        pulumi.set(__self__, "deploy_to", deploy_to)
        if deploy_type and not isinstance(deploy_type, str):
            raise TypeError("Expected argument 'deploy_type' to be a str")
        pulumi.set(__self__, "deploy_type", deploy_type)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if sgt and not isinstance(sgt, str):
            raise TypeError("Expected argument 'sgt' to be a str")
        pulumi.set(__self__, "sgt", sgt)

    @property
    @pulumi.getter(name="deployTo")
    def deploy_to(self) -> builtins.str:
        """
        Mandatory unless `deploy_type` is `ALL`
        """
        return pulumi.get(self, "deploy_to")

    @property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> builtins.str:
        """
        Deploy Type
        """
        return pulumi.get(self, "deploy_type")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the IP to SGT mapping Group
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def sgt(self) -> builtins.str:
        """
        Trustsec Security Group ID
        """
        return pulumi.get(self, "sgt")


class AwaitableGetIpToSgtMappingGroupResult(GetIpToSgtMappingGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpToSgtMappingGroupResult(
            deploy_to=self.deploy_to,
            deploy_type=self.deploy_type,
            description=self.description,
            id=self.id,
            name=self.name,
            sgt=self.sgt)


def get_ip_to_sgt_mapping_group(id: Optional[builtins.str] = None,
                                name: Optional[builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpToSgtMappingGroupResult:
    """
    This data source can read the TrustSec IP to SGT Mapping Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_ip_to_sgt_mapping_group(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the IP to SGT mapping Group
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:trustsec/getIpToSgtMappingGroup:getIpToSgtMappingGroup', __args__, opts=opts, typ=GetIpToSgtMappingGroupResult).value

    return AwaitableGetIpToSgtMappingGroupResult(
        deploy_to=pulumi.get(__ret__, 'deploy_to'),
        deploy_type=pulumi.get(__ret__, 'deploy_type'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        sgt=pulumi.get(__ret__, 'sgt'))
def get_ip_to_sgt_mapping_group_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpToSgtMappingGroupResult]:
    """
    This data source can read the TrustSec IP to SGT Mapping Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_ip_to_sgt_mapping_group(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the IP to SGT mapping Group
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:trustsec/getIpToSgtMappingGroup:getIpToSgtMappingGroup', __args__, opts=opts, typ=GetIpToSgtMappingGroupResult)
    return __ret__.apply(lambda __response__: GetIpToSgtMappingGroupResult(
        deploy_to=pulumi.get(__response__, 'deploy_to'),
        deploy_type=pulumi.get(__response__, 'deploy_type'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        sgt=pulumi.get(__response__, 'sgt')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDownloadableAclResult',
    'AwaitableGetDownloadableAclResult',
    'get_downloadable_acl',
    'get_downloadable_acl_output',
]

@pulumi.output_type
class GetDownloadableAclResult:
    """
    A collection of values returned by getDownloadableAcl.
    """
    def __init__(__self__, dacl=None, dacl_type=None, description=None, id=None, name=None):
        if dacl and not isinstance(dacl, str):
            raise TypeError("Expected argument 'dacl' to be a str")
        pulumi.set(__self__, "dacl", dacl)
        if dacl_type and not isinstance(dacl_type, str):
            raise TypeError("Expected argument 'dacl_type' to be a str")
        pulumi.set(__self__, "dacl_type", dacl_type)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def dacl(self) -> builtins.str:
        """
        The DACL content
        """
        return pulumi.get(self, "dacl")

    @property
    @pulumi.getter(name="daclType")
    def dacl_type(self) -> builtins.str:
        """
        The type of ACL
        """
        return pulumi.get(self, "dacl_type")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the downloadable ACL
        """
        return pulumi.get(self, "name")


class AwaitableGetDownloadableAclResult(GetDownloadableAclResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDownloadableAclResult(
            dacl=self.dacl,
            dacl_type=self.dacl_type,
            description=self.description,
            id=self.id,
            name=self.name)


def get_downloadable_acl(id: Optional[builtins.str] = None,
                         name: Optional[builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDownloadableAclResult:
    """
    This data source can read the Downloadable ACL.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.networkaccess.get_downloadable_acl(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the downloadable ACL
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:networkaccess/getDownloadableAcl:getDownloadableAcl', __args__, opts=opts, typ=GetDownloadableAclResult).value

    return AwaitableGetDownloadableAclResult(
        dacl=pulumi.get(__ret__, 'dacl'),
        dacl_type=pulumi.get(__ret__, 'dacl_type'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_downloadable_acl_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDownloadableAclResult]:
    """
    This data source can read the Downloadable ACL.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.networkaccess.get_downloadable_acl(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the downloadable ACL
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:networkaccess/getDownloadableAcl:getDownloadableAcl', __args__, opts=opts, typ=GetDownloadableAclResult)
    return __ret__.apply(lambda __response__: GetDownloadableAclResult(
        dacl=pulumi.get(__response__, 'dacl'),
        dacl_type=pulumi.get(__response__, 'dacl_type'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TacacsProfileArgs', 'TacacsProfile']

@pulumi.input_type
class TacacsProfileArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 session_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['TacacsProfileSessionAttributeArgs']]]] = None):
        """
        The set of arguments for constructing a TacacsProfile resource.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: The name of the TACACS profile
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if session_attributes is not None:
            pulumi.set(__self__, "session_attributes", session_attributes)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the TACACS profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="sessionAttributes")
    def session_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TacacsProfileSessionAttributeArgs']]]]:
        return pulumi.get(self, "session_attributes")

    @session_attributes.setter
    def session_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TacacsProfileSessionAttributeArgs']]]]):
        pulumi.set(self, "session_attributes", value)


@pulumi.input_type
class _TacacsProfileState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 session_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['TacacsProfileSessionAttributeArgs']]]] = None):
        """
        Input properties used for looking up and filtering TacacsProfile resources.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: The name of the TACACS profile
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if session_attributes is not None:
            pulumi.set(__self__, "session_attributes", session_attributes)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the TACACS profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="sessionAttributes")
    def session_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TacacsProfileSessionAttributeArgs']]]]:
        return pulumi.get(self, "session_attributes")

    @session_attributes.setter
    def session_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TacacsProfileSessionAttributeArgs']]]]):
        pulumi.set(self, "session_attributes", value)


class TacacsProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 session_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TacacsProfileSessionAttributeArgs', 'TacacsProfileSessionAttributeArgsDict']]]]] = None,
                 __props__=None):
        """
        This resource can manage a TACACS Profile.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.TacacsProfile("example",
            name="Profile1",
            description="My TACACS profile",
            session_attributes=[{
                "type": "MANDATORY",
                "name": "attr1",
                "value": "value",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import ise:deviceadmin/tacacsProfile:TacacsProfile example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: The name of the TACACS profile
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TacacsProfileArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a TACACS Profile.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.TacacsProfile("example",
            name="Profile1",
            description="My TACACS profile",
            session_attributes=[{
                "type": "MANDATORY",
                "name": "attr1",
                "value": "value",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import ise:deviceadmin/tacacsProfile:TacacsProfile example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param TacacsProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TacacsProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 session_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TacacsProfileSessionAttributeArgs', 'TacacsProfileSessionAttributeArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TacacsProfileArgs.__new__(TacacsProfileArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["session_attributes"] = session_attributes
        super(TacacsProfile, __self__).__init__(
            'ise:deviceadmin/tacacsProfile:TacacsProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            session_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TacacsProfileSessionAttributeArgs', 'TacacsProfileSessionAttributeArgsDict']]]]] = None) -> 'TacacsProfile':
        """
        Get an existing TacacsProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: The name of the TACACS profile
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TacacsProfileState.__new__(_TacacsProfileState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["session_attributes"] = session_attributes
        return TacacsProfile(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the TACACS profile
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="sessionAttributes")
    def session_attributes(self) -> pulumi.Output[Optional[Sequence['outputs.TacacsProfileSessionAttribute']]]:
        return pulumi.get(self, "session_attributes")

